<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    <meta http-equiv="X-UA-Compatible" content="ie=edge"/>
    <link href="{{root_}}/_assets_/styles/theme.css" rel="stylesheet" type="text/css" media="all">
    <title>
      {% if page_title %} {{page_title}} {% else %} Mikula Gallery {% endif %}
    </title>
</head>
<body>
{% block body %}{% endblock %}
</body>
</html>
