<nav class="navigation-bar">
    <ul class="navigation-page-list">
        {% for title, link in page_list_ %}
        <li>
            <a href="{{root_}}/{{link}}">{{title}}</a>
        </li>
        {% endfor %}
    </ul>
</nav>
