.navigation-page-list{
 display: flex;
 flex-direction: row;
 justify-content: centre;
}

.navigation-page-list li{
    list-style-type: none;
    margin: 10px;
}

.child-albums-list,
.thumbnails-list
 {
    list-style-type: none;
    display: grid;
    grid-template-columns: repeat(4, auto);
}

.album-default-thumbnail{
    background-image: url("../images/folder.svg");
    background-position: centre;
    background-repeat: no-repeat;
    height: 200px;
    width: auto;
    align-content: centre;
}