gallery_dir = "_gallery_"
images_dir = "images"
thumbnails_dir = "thumbnails"
assets_dir = "_assets_"
user_assets_dir = "_user-assets_"

pages_source = "__pages__"
assets_source = "__assets__"
ignored = (pages_source, assets_source, ".git")
